jactorch.parallel.dict\_gather
==============================

.. automodule:: jactorch.parallel.dict_gather

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      DictGatherDataParallel
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      data_parallel_dict_gather
      dict_gather_v1
      dict_gather_v2
      patch_dict_gathering
   
   

   
   
   








.. rubric:: Class DictGatherDataParallel
.. autoclass:: DictGatherDataParallel
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: data_parallel_dict_gather

.. autofunction:: dict_gather_v1

.. autofunction:: dict_gather_v2

.. autofunction:: patch_dict_gathering


